==> XIV_host_attach-1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/xivdiag/sunos.py <==
#!/usr/bin/env xpyv

#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os import path, environ
from commands import getoutput
from subprocess import PIPE, Popen

from interfaces import IXIVDiag
from collector.collectable.files import SimpleFileCollectable as FileItem
from collector.collectable.commands import SimpleCommandCollectable as CommandItem
from collector.collectable.directories import SimpleDirectoryCollectable as DirectoryItem

DEFAULTDIR = '/tmp'

class XIVDiag(IXIVDiag):
    def add_collectables(self):
        self.add_directories()
        self.add_files()
        self.add_commands()

    def add_directories(self):
        self.add_collectable_item(DirectoryItem('/var/adm directory', self.zip_file, "/var/adm"))
        self.add_collectable_item(DirectoryItem('/var/log directory', self.zip_file, "/var/log"))
        self.add_collectable_item(DirectoryItem('HAK log directory', self.zip_file, "/opt/xiv/host_attach/var/log"))

    def add_files(self):
        self.add_collectable_item(FileItem('scsi_vhci.conf', self.zip_file, '/kernel/drv/scsi_vhci.conf'))
        self.add_collectable_item(FileItem('fp.conf', self.zip_file, '/kernel/drv/fp.conf'))

    def add_commands(self):
        self.add_collectable_item(CommandItem("cfgadm", ['cfgadm', '-al']))
        self.add_collectable_item(CommandItem("find /dev", ['find', '/dev']))

==> XIV_host_attach-1.1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/xivdiag/sunos.py <==
#!/usr/bin/env xpyv

#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os import path, environ
from commands import getoutput
from subprocess import PIPE, Popen

from interfaces import IXIVDiag
from collector.collectable.files import SimpleFileCollectable as FileItem
from collector.collectable.commands import SimpleCommandCollectable as CommandItem
from collector.collectable.directories import SimpleDirectoryCollectable as DirectoryItem

DEFAULTDIR = '/tmp'

class XIVDiag(IXIVDiag):
    def add_collectables(self):
        self.add_directories()
        self.add_files()
        self.add_commands()

    def add_directories(self):
        self.add_collectable_item(DirectoryItem('/var/adm directory', self.zip_file, "/var/adm"))
        self.add_collectable_item(DirectoryItem('/var/log directory', self.zip_file, "/var/log"))
        self.add_collectable_item(DirectoryItem('HAK log directory', self.zip_file, "/opt/xiv/host_attach/log"))

    def add_files(self):
        self.add_collectable_item(FileItem('scsi_vhci.conf', self.zip_file, '/kernel/drv/scsi_vhci.conf'))
        self.add_collectable_item(FileItem('fp.conf', self.zip_file, '/kernel/drv/fp.conf'))

    def add_commands(self):
        self.add_collectable_item(CommandItem("cfgadm", ['cfgadm', '-al']))
        self.add_collectable_item(CommandItem("find /dev", ['find', '/dev']))
